@@ -8,25 +8,12 @@ from pyutil import fileutil, mathutil
 
 READSIZE=8192
 
-class WTF(Exception): pass
-
-def md5it(f, VERBOSITY=0):
-    bytesread = 0
-    if VERBOSITY > 2:
-        print "xxxxxx about to md5 %s" % (f,)
-
+def md5it(f):
     h = md5.new()
     d = f.read(READSIZE)
     while d:
         h.update(d)
         d = f.read(READSIZE)
-        bytesread += len(d)
-        if bytesread > 10**12:
-            raise WTF("this file is just going and going %s" % (f,))
-
-    if VERBOSITY > 2:
-        print "xxxxxx finished md5 %s" % (f,)
-
     return h.hexdigest()
 
 def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS):
@@ -36,12 +23,13 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, NOFOLL
         return _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, d1)
     finally:
         d1.close()
-        fileutil.remove_if_possible("dupfilefind_d2")
+        fileutil.remove_if_possible("dupfilefind_d1")
 
 def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, d1, next_multiple=mathutil.next_multiple):
     assert not (HARDLINKEM and DELETEEM) # at most one of these
 
-    visited = set() # to avoid symlink recursion
+    if not NOFOLLOWSYMLINKS:
+        visited = set() # to avoid symlink recursion
 
     # First pass: build map from size, dev, inode number to filenames.
     def visit(dirpath, dirnames, fnames, next_multiple=next_multiple, visited=visited):
@@ -115,13 +103,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, NOFOL
                 md5h = None
                 for fname in fnames:
                     try:
-                        if not os.path.isfile(fname):
-                            print "xxxxxx weird.  not os.path.isfile(%s)" % (fname,)
-                        try:
-                            md5h = md5it(open(fname, "rb"), VERBOSITY=VERBOSITY) # Here's the expensive part.
-                        except WTF, le:
-                            le.args = tuple(le.args + (os.stat(fname),))
-                            raise
+                        md5h = md5it(open(fname, "rb")) # Here's the expensive part.
                         break
                     except EnvironmentError, le:
                         print "note: couldn't read file named %s because %s" % (fname, le)
